@@ -14,6 +14,7 @@ from dvc.exceptions import NotDvcRepoError
 from git.exc import InvalidGitRepositoryError
 
 import calkit
+import calkit.cli.main
 from calkit.cli.main import _stage_run_info_from_log_content, _to_shell_cmd
 
 
@@ -345,8 +346,9 @@ def test_add(tmp_dir):
     with open("text.txt", "w") as f:
         f.write("Hi")
     # Create a large-ish binary file that should be added to DVC
+    binary_size = 5_100_000
     with open("large.bin", "wb") as f:
-        f.write(os.urandom(2_000_000))
+        f.write(os.urandom(binary_size))
     # Create a small directory that should be added to Git
     os.makedirs("src")
     with open("src/code.py", "w") as f:
@@ -354,7 +356,7 @@ def test_add(tmp_dir):
     # Create a large data directory that should be added to DVC
     os.makedirs("data/raw")
     with open("data/raw/file1.bin", "wb") as f:
-        f.write(os.urandom(2_000_000))
+        f.write(os.urandom(binary_size))
     # Create a file with an extension that should automatically be added to DVC
     with open("data.parquet", "w") as f:
         f.write("This is a fake parquet file")
@@ -393,12 +395,12 @@ def test_add(tmp_dir):
     subprocess.check_call(["calkit", "add", "src/code.py", "-M"])
     assert repo.head.commit.message.strip() == "Update src/code.py"
     with open("data/raw/file2.bin", "wb") as f:
-        f.write(os.urandom(2_000_000))
+        f.write(os.urandom(binary_size))
     subprocess.check_call(["calkit", "add", "data", "-M"])
     assert repo.head.commit.message.strip() == "Update data"
     os.makedirs("data2")
     with open("data2/large2.bin", "wb") as f:
-        f.write(os.urandom(2_000_000))
+        f.write(os.urandom(binary_size))
     subprocess.check_call(["calkit", "add", "data2", "-M"])
     assert repo.head.commit.message.strip() == "Add data2"
     subprocess.check_call(["calkit", "add", "--to", "dvc", "large.bin"])
@@ -549,6 +551,9 @@ def test_run(tmp_dir):
         ]
     )
     subprocess.check_call(["calkit", "run"])
+    res = calkit.cli.main.run()
+    assert "dvc_stages" in res
+    assert "stage_run_info" in res
 
 
 def test_stage_run_info_from_log_content():
