@@ -1,5 +1,6 @@
 """Tests for the ``dvc`` module."""
 
+import os
 import subprocess
 
 import calkit
@@ -35,3 +36,13 @@ def test_get_remotes(tmp_dir):
             "https://sup.com/this/is/a/long/remote/url/so/test/this"
         ),
     }
+
+
+def test_hash_directory():
+    res = calkit.dvc.hash_directory("test/dvc-md5-dir")
+    print("CWD:", os.getcwd())
+    print("Contents:", os.listdir("test/dvc-md5-dir"))
+    assert res["nfiles"] == 1
+    assert res["size"] == 1226
+    assert res["hash"] == "md5"
+    assert res["md5"] == "ca2ffab71e00d528b974e583d789ec97.dir"
